@@ -30,5 +30,12 @@
 #endif // __GNUC__
 #endif // BCTBX_NO_BREAK
 
+#ifndef UNUSED
+#ifdef __GNUC__
+#  define UNUSED(x) x __attribute__((__unused__))
+#else
+#  define UNUSED(x) x
+#endif // __GNUC__
+#endif // UNUSED
 
 #endif /* BCTBX_DEFS_H_ */
